@@ -1,8 +1,8 @@
 /*
- * jets3t : Java Extra-Tasty S3 Toolkit (for Amazon S3 online storage service)
- * This is a java.net project, see https://jets3t.dev.java.net/
+ * JetS3t : Java S3 Toolkit
+ * Project hosted at http://bitbucket.org/jmurty/jets3t/
  *
- * Copyright 2006 James Murty
+ * Copyright 2006-2010 James Murty
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -68,7 +68,7 @@ import org.jets3t.service.utils.FileComparer.PartialObjectListing;
  * @author James Murty
  */
 public class Synchronize {
-    public static final String APPLICATION_DESCRIPTION = "Synchronize/0.7.3";
+    public static final String APPLICATION_DESCRIPTION = "Synchronize/0.7.4-dev";
 
     protected static final int REPORT_LEVEL_NONE = 0;
     protected static final int REPORT_LEVEL_ACTIONS = 1;
@@ -258,12 +258,9 @@ public class Synchronize {
     }
 
     /**
-     * Prints text to StdOut provided the isQuiet flag is not set.
+     * Prints text to StdOut provided the isQuiet and isNoProgress flags are not set.
      *
      * @param line the text to print
-     * @param isProgressMessage
-     * if true, the line is printed followed by a carriage return such
-     * that the next line output to the console will overwrite it.
      */
     private void printProgressLine(String line) {
         if (isQuiet || isNoProgress) {
@@ -539,7 +536,7 @@ public class Synchronize {
         }
 
         printOutputLine(
-            doAction ? "" : "[No Action] " +
+            (doAction ? "" : "[No Action] ") +
             "New files: " + mergedDiscrepancyResults.onlyOnClientKeys.size() +
             ", Updated: " + mergedDiscrepancyResults.updatedOnClientKeys.size() +
             (isKeepFiles?
@@ -776,6 +773,7 @@ public class Synchronize {
         }
 
         printOutputLine(
+            (doAction ? "" : "[No Action] ") +
             "New files: " + mergedDiscrepancyResults.onlyOnServerKeys.size() +
             ", Updated: " + mergedDiscrepancyResults.updatedOnServerKeys.size() +
             (isKeepFiles?
@@ -883,13 +881,23 @@ public class Synchronize {
                 // Bucket does not exist in this user's account, try creating it.
                 try {
                     bucket = s3Service.createBucket(new S3Bucket(bucketName));
-                } catch (Exception e) {
-                    throw new SynchronizeException("Unable to create/connect to S3 bucket: " + bucketName, e);
+                } catch (S3ServiceException e) {
+                    // Bucket could not be created, someone else must own it.
+                    try {
+                        // Let's see if we can at least access the bucket...
+                        s3Service.listObjectsChunked(bucketName, null, null, 1, null, false);
+                        // ... if we get this far we're dealing with a third-party
+                        // bucket we can read. That's fine, let's proceed.
+                        bucket = new S3Bucket(bucketName);
+                    } catch (S3ServiceException e2) {
+                        // We can't create or access this bucket, time to give up.
+                        throw new SynchronizeException(
+                            "Unable to create or access S3 bucket: " + bucketName, e);
+                    }
                 }
             }
         }
 
-
         boolean storeEmptyDirectories = properties
             .getBoolProperty("uploads.storeEmptyDirectories", true);
 
