@@ -1,8 +1,8 @@
 /*
- * jets3t : Java Extra-Tasty S3 Toolkit (for Amazon S3 online storage service)
- * This is a java.net project, see https://jets3t.dev.java.net/
+ * JetS3t : Java S3 Toolkit
+ * Project hosted at http://bitbucket.org/jmurty/jets3t/
  *
- * Copyright 2006 James Murty
+ * Copyright 2006-2010 James Murty
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -104,7 +104,6 @@ import org.jets3t.gui.JHtmlLabel;
 import org.jets3t.gui.UserInputFields;
 import org.jets3t.gui.skins.SkinsFactory;
 import org.jets3t.service.Jets3tProperties;
-import org.jets3t.service.S3Service;
 import org.jets3t.service.S3ServiceException;
 import org.jets3t.service.impl.rest.httpclient.RestS3Service;
 import org.jets3t.service.io.BytesProgressWatcher;
@@ -151,15 +150,15 @@ import com.centerkey.utils.BareBonesBrowserLaunch;
  * @author James Murty
  */
 public class Uploader extends JApplet implements S3ServiceEventListener, ActionListener, ListSelectionListener, HyperlinkActivatedListener, CredentialsProvider {
-    private static final long serialVersionUID = -1648566055636164308L;
+    private static final long serialVersionUID = 2759324769352022783L;
 
     private static final Log log = LogFactory.getLog(Uploader.class);
 
-    public static final String APPLICATION_DESCRIPTION = "Uploader/0.7.3";
+    public static final String APPLICATION_DESCRIPTION = "Uploader/0.7.4-dev";
 
     public static final String UPLOADER_PROPERTIES_FILENAME = "uploader.properties";
 
-    private static final String UPLOADER_VERSION_ID = "JetS3t Uploader/0.7.3";
+    private static final String UPLOADER_VERSION_ID = "JetS3t Uploader/0.7.4-dev";
 
     public static final int WIZARD_SCREEN_1 = 1;
     public static final int WIZARD_SCREEN_2 = 2;
@@ -796,6 +795,7 @@ public class Uploader extends JApplet implements S3ServiceEventListener, ActionL
         Date expiryDate = cal.getTime();
 
         AWSCredentials awsCredentials = new AWSCredentials(awsAccessKey, awsSecretKey);
+        RestS3Service s3Service = new RestS3Service(awsCredentials);
 
         try {
             /*
@@ -806,8 +806,9 @@ public class Uploader extends JApplet implements S3ServiceEventListener, ActionL
             gatekeeperMessage.addApplicationProperties(parametersMap); // Add any Applet/Application parameters as application properties.
 
             for (int i = 0; i < objects.length; i++) {
-                String signedPutUrl = S3Service.createSignedPutUrl(s3BucketName, objects[i].getKey(),
-                    objects[i].getMetadataMap(), awsCredentials, expiryDate, false);
+                String signedPutUrl = s3Service.createSignedPutUrl(
+                    s3BucketName, objects[i].getKey(), objects[i].getMetadataMap(),
+                    expiryDate, false);
 
                 SignatureRequest signatureRequest = new SignatureRequest(
                     SignatureRequest.SIGNATURE_TYPE_PUT, objects[i].getKey());
