@@ -1,8 +1,8 @@
 /*
- * jets3t : Java Extra-Tasty S3 Toolkit (for Amazon S3 online storage service)
- * This is a java.net project, see https://jets3t.dev.java.net/
+ * JetS3t : Java S3 Toolkit
+ * Project hosted at http://bitbucket.org/jmurty/jets3t/
  *
- * Copyright 2006 James Murty
+ * Copyright 2006-2010 James Murty
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -74,7 +74,7 @@ public class CodeSamples {
 
         // To communicate with S3, create a class that implements an S3Service.
         // We will use the REST/HTTP implementation based on HttpClient, as this is the most
-        // robust implementation provided with jets3t.
+        // robust implementation provided with JetS3t.
 
         S3Service s3Service = new RestS3Service(awsCredentials);
 
@@ -99,10 +99,13 @@ public class CodeSamples {
         // To create a bucket in an S3 data center located somewhere other than
         // the United States, you can specify a location for your bucket as a
         // second parameter to the createBucket() method. Currently, the alternative
-        // S3 locations are Europe (EU) and US West - Northern California (us-west-1).
+        // S3 locations are Europe (EU), US West - Northern California (us-west-1),
+        // and Asia Pacific (Singapore)
 
         S3Bucket euBucket = s3Service.createBucket("eu-bucket", S3Bucket.LOCATION_EUROPE);
         S3Bucket usWestBucket = s3Service.createBucket("us-west-bucket", S3Bucket.LOCATION_US_WEST);
+        S3Bucket asiaPacificBucket = s3Service.createBucket(
+            "asia-pacific-bucket", S3Bucket.LOCATION_ASIA_PACIFIC);
 
 
         /*
@@ -155,7 +158,8 @@ public class CodeSamples {
         ByteArrayInputStream greetingIS = new ByteArrayInputStream(
             greeting.getBytes(Constants.DEFAULT_ENCODING));
         helloWorldObject.setDataInputStream(greetingIS);
-        helloWorldObject.setContentLength(greetingIS.available());
+        helloWorldObject.setContentLength(
+            greeting.getBytes(Constants.DEFAULT_ENCODING).length);
         helloWorldObject.setContentType("text/plain");
 
         // Upload the data objects.
@@ -166,6 +170,17 @@ public class CodeSamples {
         // Print details about the uploaded object.
         System.out.println("S3Object with data: " + helloWorldObject);
 
+        // You may want to store your objects using a non-standard
+        // "storage class" in some cases, such as if you are prepared to
+        // accept a reduced level of redundancy in exchange for cheaper
+        // storage. Here is how you store an object using the
+        // Reduced Redundancy Storage (RRS) feature.
+        S3Object rrsObject = new S3Object("reduced-redundancy-object");
+        // Apply the RRS storage class instead of the default STANDARD one.
+        rrsObject.setStorageClass(S3Object.STORAGE_CLASS_REDUCED_REDUNDANCY);
+        // Upload the object as usual.
+        s3Service.putObject(testBucket, rrsObject);
+
         /*
          * Verifying Uploads
          */
@@ -351,11 +366,11 @@ public class CodeSamples {
          * ***********************
          */
 
-        // The jets3t Toolkit includes utility services, S3ServiceMulti and S3ServiceSimpleMulti, that
+        // The JetS3t Toolkit includes utility services, S3ServiceMulti and S3ServiceSimpleMulti, that
         // can perform an S3 operation on many objects at a time. These services allow you to use more
         // of your available bandwidth and perform S3 operations much faster. They work with any
         // thread-safe S3Service implementation, such as the HTTP/REST and SOAP implementations
-        // provided with jets3t.
+        // provided with JetS3t.
 
         // The S3ServiceMulti service is intended for advanced developers. It is designed for use in
         // graphical applications and uses an event-notification approach to communicate its results
@@ -465,7 +480,7 @@ public class CodeSamples {
          * your objects when they are updated or deleted. This feature means you can be much
          * more confident that vital data will not be lost even if it is accidentally
          * overwritten or deleted.
-         * 
+         *
          * Versioning is not enabled for a bucket by default, you must explicitly enable
          * it. Once it is enabled you access and mange object versions using unique version
          * identifiers.
@@ -572,9 +587,9 @@ public class CodeSamples {
         // if you are the owner of the bucket containing the version.
         s3Service.deleteVersionedObject(finalVersionId,
             vBucketName, "versioned-object");
-        
+
         // You can easily delete all the versions of an object using
-        // one of JetS3t's multi-threaded services. 
+        // one of JetS3t's multi-threaded services.
         versions = s3Service.getObjectVersions(vBucketName, "versioned-object");
         // Convert version and delete marker objects into versionId strings.
         String[] versionIds = BaseVersionOrDeleteMarker.toVersionIds(versions);
@@ -588,7 +603,7 @@ public class CodeSamples {
         //////////////////////////////////////////////////////////////
 
         // Require multi-factor authentication to delete versions.
-        s3Service.enableBucketVersioningWithMFA(vBucketName);
+        s3Service.enableBucketVersioningAndMFA(vBucketName);
 
         // Check MFA status for the bucket
         versioningStatus = s3Service.getBucketVersioningStatus(vBucketName);
@@ -642,7 +657,7 @@ public class CodeSamples {
          */
 
         // AWS credentials are your means to login to and manage your S3 account, and should be
-        // kept secure. The jets3t toolkit stores these credentials in AWSCredentials objects.
+        // kept secure. The JetS3t toolkit stores these credentials in AWSCredentials objects.
         // The AWSCredentials class provides utility methods to allow credentials to be saved to
         // an encrypted file and loaded from a previously saved file with the right password.
 
@@ -667,7 +682,7 @@ public class CodeSamples {
 
         // S3 uses Access Control Lists to control who has access to buckets and objects in S3.
         // By default, any bucket or object you create will belong to you and will not be accessible
-        // to anyone else. You can use jets3t's support for access control lists to make buckets or
+        // to anyone else. You can use JetS3t's support for access control lists to make buckets or
         // objects publicly accessible, or to allow other S3 members to access or manage your objects.
 
         // The ACL capabilities of S3 are quite involved, so to understand this subject fully please
@@ -747,8 +762,8 @@ public class CodeSamples {
         // If you use the generated URL in a web browser within 5 minutes, you will be able to view
         // the object's contents. After 5 minutes, the URL will no longer work and you will only
         // see an Access Denied message.
-        String signedUrl = S3Service.createSignedGetUrl(privateBucket.getName(), privateObject.getKey(),
-            awsCredentials, expiryDate, false);
+        String signedUrl = s3Service.createSignedGetUrl(
+            privateBucket.getName(), privateObject.getKey(), expiryDate, false);
         System.out.println("Signed URL: " + signedUrl);
 
 
@@ -876,10 +891,9 @@ public class CodeSamples {
         boolean isDnsBucketNamingDisabled = false;
 
         String requesterPaysSignedGetUrl =
-            S3Service.createSignedUrl("GET", bucketName, "object-name",
+            s3Service.createSignedUrl("GET", bucketName, "object-name",
                 Constants.REQUESTER_PAYS_BUCKET_FLAG, // Include Requester Pays flag
-                httpHeaders,
-                awsCredentials, expirySecsAfterEpoch,
+                httpHeaders, expirySecsAfterEpoch,
                 isVirtualHost, isHttpsUrl,
                 isDnsBucketNamingDisabled);
 
@@ -908,9 +922,8 @@ public class CodeSamples {
         cal = Calendar.getInstance();
         cal.add(Calendar.MINUTE, 5);
 
-        String signedDevPayUrl = S3Service.createSignedGetUrl(
-            "devpay-bucket-name", "devpay-object-name",
-            devPayCredentials, cal.getTime());
+        String signedDevPayUrl = devPayService.createSignedGetUrl(
+            "devpay-bucket-name", "devpay-object-name", cal.getTime());
 
     }
 
