@@ -1,6 +1,6 @@
 /*
- * jets3t : Java Extra-Tasty S3 Toolkit (for Amazon S3 online storage service)
- * This is a java.net project, see https://jets3t.dev.java.net/
+ * JetS3t : Java S3 Toolkit
+ * Project hosted at http://bitbucket.org/jmurty/jets3t/
  *
  * Copyright 2008 - 2009 James Murty
  *
@@ -77,7 +77,7 @@ public class CloudFrontService implements AWSRequestAuthorizer {
     private static final Log log = LogFactory.getLog(CloudFrontService.class);
 
     public static final String ENDPOINT = "https://cloudfront.amazonaws.com/";
-    public static final String VERSION = "2010-03-01";
+    public static final String VERSION = "2010-06-01";
     public static final String XML_NAMESPACE = "http://cloudfront.amazonaws.com/doc/" + VERSION + "/";
     public static final String DEFAULT_BUCKET_SUFFIX = ".s3.amazonaws.com";
     public static final String ORIGIN_ACCESS_IDENTITY_URI_PATH = "/origin-access-identity/cloudfront";
@@ -154,14 +154,15 @@ public class CloudFrontService implements AWSRequestAuthorizer {
 
         // Retrieve Proxy settings.
         if (this.jets3tProperties.getBoolProperty("httpclient.proxy-autodetect", true)) {
-            RestUtils.initHttpProxy(this.httpClient);
+            RestUtils.initHttpProxy(this.httpClient, this.jets3tProperties);
         } else {
             String proxyHostAddress = this.jets3tProperties.getStringProperty("httpclient.proxy-host", null);
             int proxyPort = this.jets3tProperties.getIntProperty("httpclient.proxy-port", -1);
             String proxyUser = this.jets3tProperties.getStringProperty("httpclient.proxy-user", null);
             String proxyPassword = this.jets3tProperties.getStringProperty("httpclient.proxy-password", null);
             String proxyDomain = this.jets3tProperties.getStringProperty("httpclient.proxy-domain", null);
-            RestUtils.initHttpProxy(this.httpClient, proxyHostAddress, proxyPort, proxyUser, proxyPassword, proxyDomain);
+            RestUtils.initHttpProxy(this.httpClient, this.jets3tProperties,
+                proxyHostAddress, proxyPort, proxyUser, proxyPassword, proxyDomain);
         }
 
         /* TODO: CloudFront service does not seem to support 100-continue protocol for 2009-04-02
@@ -440,6 +441,8 @@ public class CloudFrontService implements AWSRequestAuthorizer {
     public List listDistributionsByBucketName(boolean isStreaming, String bucketName)
         throws CloudFrontServiceException
     {
+        String s3Endpoint = this.jets3tProperties.getStringProperty(
+            "s3service.s3-endpoint", Constants.S3_DEFAULT_HOSTNAME);
         if (log.isDebugEnabled()) {
             log.debug("Listing "
             	+ (isStreaming ? "streaming" : "")
@@ -452,7 +455,8 @@ public class CloudFrontService implements AWSRequestAuthorizer {
         for (int i = 0; i < allDistributions.length; i++) {
             String distributionOrigin = allDistributions[i].getOrigin();
             if (distributionOrigin.equals(bucketName)
-                || bucketName.equals(ServiceUtils.findBucketNameInHostname(distributionOrigin)))
+                || bucketName.equals(ServiceUtils.findBucketNameInHostname(
+                    distributionOrigin, s3Endpoint)))
             {
                 bucketDistributions.add(allDistributions[i]);
             }
@@ -509,6 +513,7 @@ public class CloudFrontService implements AWSRequestAuthorizer {
      * @param originAccessIdentityId
      * @param trustedSignerSelf
      * @param trustedSignerAwsAccountNumbers
+     * @param requiredProtocols
      * @return
      * XML document representing a Distribution Configuration
      * @throws TransformerException
@@ -518,7 +523,7 @@ public class CloudFrontService implements AWSRequestAuthorizer {
     protected String buildDistributionConfigXmlDocument(boolean isStreamingDistribution,
     	String origin, String callerReference, String[] cnames, String comment, boolean enabled,
     	LoggingStatus loggingStatus, String originAccessIdentityId, boolean trustedSignerSelf,
-        String[] trustedSignerAwsAccountNumbers)
+        String[] trustedSignerAwsAccountNumbers, String[] requiredProtocols)
     	throws TransformerException, ParserConfigurationException, FactoryConfigurationError
     {
         XMLBuilder builder = XMLBuilder.create(
@@ -561,6 +566,12 @@ public class CloudFrontService implements AWSRequestAuthorizer {
         		.e("Prefix").t(loggingStatus.getPrefix()).up()
         	.up();
         }
+        if (requiredProtocols != null && requiredProtocols.length > 0) {
+            XMLBuilder rpsBuilder = builder.e("RequiredProtocols");
+            for (int i = 0; i < requiredProtocols.length; i++) {
+                rpsBuilder.e("Protocol").t(requiredProtocols[i]).up();
+            }
+        }
         return builder.asString(null);
     }
 
@@ -576,6 +587,7 @@ public class CloudFrontService implements AWSRequestAuthorizer {
      * @param originAccessIdentityId
      * @param trustedSignerSelf
      * @param trustedSignerAwsAccountNumbers
+     * @param requiredProtocols
      * @return
      * Information about the newly-created distribution.
      * @throws CloudFrontServiceException
@@ -584,7 +596,8 @@ public class CloudFrontService implements AWSRequestAuthorizer {
     	boolean isStreaming, String origin, String callerReference,
         String[] cnames, String comment, boolean enabled, LoggingStatus loggingStatus,
         String originAccessIdentityId, boolean trustedSignerSelf,
-        String[] trustedSignerAwsAccountNumbers) throws CloudFrontServiceException
+        String[] trustedSignerAwsAccountNumbers, String[] requiredProtocols)
+        throws CloudFrontServiceException
     {
         if (log.isDebugEnabled()) {
             log.debug("Creating "
@@ -608,9 +621,10 @@ public class CloudFrontService implements AWSRequestAuthorizer {
         	+ (isStreaming ? "/streaming-distribution" : "/distribution"));
 
         try {
-            String distributionConfigXml = buildDistributionConfigXmlDocument(isStreaming,
-        		origin, callerReference, cnames, comment, enabled, loggingStatus,
-        		originAccessIdentityId, trustedSignerSelf, trustedSignerAwsAccountNumbers);
+            String distributionConfigXml = buildDistributionConfigXmlDocument(
+                isStreaming, origin, callerReference, cnames, comment, enabled,
+                loggingStatus, originAccessIdentityId, trustedSignerSelf,
+                trustedSignerAwsAccountNumbers, requiredProtocols);
 
             httpMethod.setRequestEntity(
                 new StringRequestEntity(distributionConfigXml, "text/xml", Constants.DEFAULT_ENCODING));
@@ -668,6 +682,10 @@ public class CloudFrontService implements AWSRequestAuthorizer {
      * signed URLs. Note: If either trustedSignerSelf or
      * trustedSignerAwsAccountNumbers parameters are provided the private distribution
      * will require signed URLs to access content.
+     * @param requiredProtocols
+     * List of protocols that must be used by clients to retrieve content from the
+     * distribution. If this value is null or is an empty array, all protocols will be
+     * supported.
      *
      * @return
      * an object that describes the newly-created distribution, in particular the
@@ -678,11 +696,12 @@ public class CloudFrontService implements AWSRequestAuthorizer {
     public Distribution createDistribution(String origin, String callerReference,
         String[] cnames, String comment, boolean enabled, LoggingStatus loggingStatus,
         String originAccessIdentityId, boolean trustedSignerSelf,
-        String[] trustedSignerAwsAccountNumbers) throws CloudFrontServiceException
+        String[] trustedSignerAwsAccountNumbers, String[] requiredProtocols)
+        throws CloudFrontServiceException
     {
         return createDistributionImpl(false, origin, callerReference, cnames, comment,
     		enabled, loggingStatus, originAccessIdentityId, trustedSignerSelf,
-    		trustedSignerAwsAccountNumbers);
+    		trustedSignerAwsAccountNumbers, requiredProtocols);
     }
 
     /**
@@ -737,7 +756,7 @@ public class CloudFrontService implements AWSRequestAuthorizer {
         throws CloudFrontServiceException
     {
         return createDistribution(origin, callerReference, cnames, comment, enabled,
-        		loggingStatus, null, false, null);
+        		loggingStatus, null, false, null, null);
     }
 
      /**
@@ -759,7 +778,9 @@ public class CloudFrontService implements AWSRequestAuthorizer {
         return createDistribution(config.getOrigin(), config.getCallerReference(),
     		config.getCNAMEs(), config.getComment(), config.isEnabled(),
     		config.getLoggingStatus(), config.getOrigin(),
-    		config.isTrustedSignerSelf(), config.getTrustedSignerAwsAccountNumbers());
+    		config.isTrustedSignerSelf(),
+    		config.getTrustedSignerAwsAccountNumbers(),
+    		config.getRequiredProtocols());
     }
 
     /**
@@ -780,6 +801,9 @@ public class CloudFrontService implements AWSRequestAuthorizer {
      * (max 128 characters). May be null.
      * @param enabled
      * Should the distribution should be enabled and publicly accessible upon creation?
+     * @param loggingStatus
+     * Logging status settings (bucket, prefix) for the distribution. If this value
+     * is null, logging will be disabled for the distribution.
      * @param originAccessIdentityId
      * Identifier of the origin access identity that can authorize access to
      * S3 objects via a private distribution. If provided the distribution will be
@@ -804,13 +828,14 @@ public class CloudFrontService implements AWSRequestAuthorizer {
      * @throws CloudFrontServiceException
      */
     public StreamingDistribution createStreamingDistribution(String origin, String callerReference,
-            String[] cnames, String comment, boolean enabled,
+            String[] cnames, String comment, boolean enabled, LoggingStatus loggingStatus,
             String originAccessIdentityId, boolean trustedSignerSelf,
-            String[] trustedSignerAwsAccountNumbers) throws CloudFrontServiceException
+            String[] trustedSignerAwsAccountNumbers)
+        throws CloudFrontServiceException
     {
         return (StreamingDistribution) createDistributionImpl(true, origin, callerReference,
-    		cnames, comment, enabled, null, originAccessIdentityId,
-    		trustedSignerSelf, trustedSignerAwsAccountNumbers);
+    		cnames, comment, enabled, loggingStatus, originAccessIdentityId,
+    		trustedSignerSelf, trustedSignerAwsAccountNumbers, null);
     }
 
     /**
@@ -831,6 +856,9 @@ public class CloudFrontService implements AWSRequestAuthorizer {
      * (max 128 characters). May be null.
      * @param enabled
      * Should the distribution should be enabled and publicly accessible upon creation?
+     * @param loggingStatus
+     * Logging status settings (bucket, prefix) for the distribution. If this value
+     * is null, logging will be disabled for the distribution.
      *
      * @return
      * an object that describes the newly-created distribution, in particular the
@@ -839,10 +867,11 @@ public class CloudFrontService implements AWSRequestAuthorizer {
      * @throws CloudFrontServiceException
      */
     public StreamingDistribution createStreamingDistribution(String origin, String callerReference,
-            String[] cnames, String comment, boolean enabled) throws CloudFrontServiceException
+            String[] cnames, String comment, boolean enabled, LoggingStatus loggingStatus)
+        throws CloudFrontServiceException
     {
         return (StreamingDistribution) createDistributionImpl(true, origin, callerReference,
-            cnames, comment, enabled, null, null, false, null);
+            cnames, comment, enabled, loggingStatus, null, false, null, null);
     }
 
     /**
@@ -1004,6 +1033,8 @@ public class CloudFrontService implements AWSRequestAuthorizer {
      * @param originAccessIdentityId
      * @param trustedSignerSelf
      * @param trustedSignerAwsAccountNumbers
+     * @param requiredProtocols
+
      * @return
      * Information about the updated distribution configuration.
      * @throws CloudFrontServiceException
@@ -1012,7 +1043,8 @@ public class CloudFrontService implements AWSRequestAuthorizer {
     	boolean isStreaming, String id, String[] cnames,
         String comment, boolean enabled, LoggingStatus loggingStatus,
         String originAccessIdentityId, boolean trustedSignerSelf,
-        String[] trustedSignerAwsAccountNumbers)
+        String[] trustedSignerAwsAccountNumbers,
+        String[] requiredProtocols)
         throws CloudFrontServiceException
     {
         if (log.isDebugEnabled()) {
@@ -1041,7 +1073,7 @@ public class CloudFrontService implements AWSRequestAuthorizer {
             String distributionConfigXml = buildDistributionConfigXmlDocument(isStreaming,
             		oldConfig.getOrigin(), oldConfig.getCallerReference(), cnames, comment, enabled,
             		loggingStatus, originAccessIdentityId, trustedSignerSelf,
-            		trustedSignerAwsAccountNumbers);
+            		trustedSignerAwsAccountNumbers, requiredProtocols);
 
             httpMethod.setRequestEntity(
                 new StringRequestEntity(distributionConfigXml, "text/xml", Constants.DEFAULT_ENCODING));
@@ -1106,6 +1138,10 @@ public class CloudFrontService implements AWSRequestAuthorizer {
      * signed URLs. Note: If either trustedSignerSelf or
      * trustedSignerAwsAccountNumbers parameters are provided the private distribution
      * will require signed URLs to access content.
+     * @param requiredProtocols
+     * List of protocols that must be used by clients to retrieve content from the
+     * distribution. If this value is null or is an empty array all protocols will be
+     * permitted.
      *
      * @return
      * an object that describes the distribution's updated configuration, including its
@@ -1116,11 +1152,12 @@ public class CloudFrontService implements AWSRequestAuthorizer {
     public DistributionConfig updateDistributionConfig(String id, String[] cnames,
         String comment, boolean enabled, LoggingStatus loggingStatus,
         String originAccessIdentityId, boolean trustedSignerSelf,
-        String[] trustedSignerAwsAccountNumbers)
+        String[] trustedSignerAwsAccountNumbers, String[] requiredProtocols)
         throws CloudFrontServiceException
     {
         return updateDistributionConfigImpl(false, id, cnames, comment, enabled, loggingStatus,
-    		originAccessIdentityId, trustedSignerSelf, trustedSignerAwsAccountNumbers);
+    		originAccessIdentityId, trustedSignerSelf, trustedSignerAwsAccountNumbers,
+    		requiredProtocols);
     }
 
     /**
@@ -1144,6 +1181,9 @@ public class CloudFrontService implements AWSRequestAuthorizer {
      * @param enabled
      * Should the distribution should be enabled and publicly accessible after the
      * configuration update?
+     * @param loggingStatus
+     * Logging status settings (bucket, prefix) for the distribution. If this value
+     * is null, logging will be disabled for the distribution.
      *
      * @return
      * an object that describes the distribution's updated configuration, including its
@@ -1152,11 +1192,70 @@ public class CloudFrontService implements AWSRequestAuthorizer {
      * @throws CloudFrontServiceException
      */
     public StreamingDistributionConfig updateStreamingDistributionConfig(
-    	String id, String[] cnames, String comment, boolean enabled)
+    	String id, String[] cnames, String comment, boolean enabled,
+    	LoggingStatus loggingStatus)
         throws CloudFrontServiceException
     {
         return (StreamingDistributionConfig) updateDistributionConfigImpl(
-    		true, id, cnames, comment, enabled, null, null, false, null);
+    		true, id, cnames, comment, enabled, loggingStatus, null, false, null, null);
+    }
+
+    /**
+     * Update the configuration of an existing streaming distribution to change its
+     * properties. The new configuration properties provided <strong>replace</strong>
+     * any existing configuration, and may take some time to be fully applied.
+     * <p>
+     * This method performs all the steps necessary to update the configuration. It
+     * first performs lookup on the distribution  using
+     * {@link #getDistributionConfig(String)} to find its origin and caller reference
+     * values, then uses this information to apply your configuration changes.
+     *
+     * @param id
+     * the distribution's unique identifier.
+     * @param cnames
+     * A list of up to 10 CNAME aliases to associate with the distribution. This
+     * parameter may be null, in which case the original CNAME aliases are retained.
+     * @param comment
+     * An optional comment to describe the distribution in your own terms
+     * (max 128 characters). May be null, in which case the original comment is retained.
+     * @param enabled
+     * Should the distribution should be enabled and publicly accessible after the
+     * configuration update?
+     * @param loggingStatus
+     * Logging status settings (bucket, prefix) for the distribution. If this value
+     * is null, logging will be disabled for the distribution.
+     * @param originAccessIdentityId
+     * Identifier of the origin access identity that can authorize access to
+     * S3 objects via a private distribution. If provided the distribution will be
+     * private, if null the distribution will be be public.
+     * @param trustedSignerSelf
+     * If true the owner of the distribution (you) will be be allowed to generate
+     * signed URLs for a private distribution. Note: If either trustedSignerSelf or
+     * trustedSignerAwsAccountNumbers parameters are provided the private distribution
+     * will require signed URLs to access content.
+     * @param trustedSignerAwsAccountNumbers
+     * Account Number identifiers for AWS account holders other than the
+     * distribution's owner who will be allowed to generate signed URLs for a private
+     * distribution. If null or empty, no additional AWS account holders may generate
+     * signed URLs. Note: If either trustedSignerSelf or
+     * trustedSignerAwsAccountNumbers parameters are provided the private distribution
+     * will require signed URLs to access content.
+     *
+     * @return
+     * an object that describes the distribution's updated configuration, including its
+     * origin bucket and CNAME aliases.
+     *
+     * @throws CloudFrontServiceException
+     */
+    public StreamingDistributionConfig updateStreamingDistributionConfig(
+        String id, String[] cnames, String comment, boolean enabled,
+        LoggingStatus loggingStatus, String originAccessIdentityId,
+        boolean trustedSignerSelf, String[] trustedSignerAwsAccountNumbers)
+        throws CloudFrontServiceException
+    {
+        return (StreamingDistributionConfig) updateDistributionConfigImpl(
+            true, id, cnames, comment, enabled, loggingStatus, originAccessIdentityId,
+            trustedSignerSelf, trustedSignerAwsAccountNumbers, null);
     }
 
     /**
@@ -1190,12 +1289,13 @@ public class CloudFrontService implements AWSRequestAuthorizer {
      * origin bucket and CNAME aliases.
      *
      * @throws CloudFrontServiceException
-     */    public DistributionConfig updateDistributionConfig(String id, String[] cnames,
+     */
+    public DistributionConfig updateDistributionConfig(String id, String[] cnames,
         String comment, boolean enabled, LoggingStatus loggingStatus)
         throws CloudFrontServiceException
     {
         return updateDistributionConfig(id, cnames, comment, enabled, loggingStatus,
-    		null, false, null);
+    		null, false, null, null);
     }
 
      /**
@@ -1225,7 +1325,8 @@ public class CloudFrontService implements AWSRequestAuthorizer {
     {
         return updateDistributionConfig(id, config.getCNAMEs(), config.getComment(),
     		config.isEnabled(), config.getLoggingStatus(), config.getOriginAccessIdentity(),
-    		config.isTrustedSignerSelf(), config.getTrustedSignerAwsAccountNumbers());
+    		config.isTrustedSignerSelf(), config.getTrustedSignerAwsAccountNumbers(),
+    		config.getRequiredProtocols());
     }
 
     /**
@@ -1253,7 +1354,7 @@ public class CloudFrontService implements AWSRequestAuthorizer {
     /**
      * Convenience method to disable a streaming distribution that you intend to delete.
      * This method merely calls the
-     * {@link #updateStreamingDistributionConfig(String, String[], String, boolean)}
+     * {@link #updateStreamingDistributionConfig(String, String[], String, boolean, LoggingStatus)}
      * method with default values for most of the distribution's configuration
      * settings.
      * <p>
@@ -1269,7 +1370,10 @@ public class CloudFrontService implements AWSRequestAuthorizer {
     public void disableStreamingDistributionForDeletion(String id)
     	throws CloudFrontServiceException
     {
-    	updateStreamingDistributionConfig(id, new String[] {}, "Disabled prior to deletion", false);
+    	updateStreamingDistributionConfig(id, new String[] {}, "Disabled prior to deletion",
+    	    false, // enabled?
+    	    null // LoggingStatus
+    	    );
     }
 
     /**
