@@ -1,6 +1,6 @@
 /*
- * jets3t : Java Extra-Tasty S3 Toolkit (for Amazon S3 online storage service)
- * This is a java.net project, see https://jets3t.dev.java.net/
+ * JetS3t : Java S3 Toolkit
+ * Project hosted at http://bitbucket.org/jmurty/jets3t/
  *
  * Copyright 2008-2010 James Murty
  *
@@ -73,20 +73,7 @@ public class CloudFrontXmlResponsesSaxParser {
      */
     public CloudFrontXmlResponsesSaxParser(Jets3tProperties properties) throws S3ServiceException {
         this.properties = properties;
-
-        // Ensure we can load the XML Reader.
-        try {
-            xr = XMLReaderFactory.createXMLReader();
-        } catch (SAXException e) {
-            // oops, lets try doing this (needed in 1.4)
-            System.setProperty("org.xml.sax.driver", "org.apache.crimson.parser.XMLReaderImpl");
-            try {
-                // Try once more...
-                xr = XMLReaderFactory.createXMLReader();
-            } catch (SAXException e2) {
-                throw new S3ServiceException("Couldn't initialize a sax driver for the XMLReader");
-            }
-        }
+        this.xr = ServiceUtils.loadXMLReader();
     }
 
     /**
@@ -363,6 +350,7 @@ public class CloudFrontXmlResponsesSaxParser {
         private String originAccessIdentity = null;
         private boolean trustedSignerSelf = false;
         private List trustedSignerAwsAccountNumberList = new ArrayList();
+        private List requiredProtocols = new ArrayList();
 
         public DistributionConfig getDistributionConfig() {
             return distributionConfig;
@@ -412,13 +400,20 @@ public class CloudFrontXmlResponsesSaxParser {
             this.trustedSignerAwsAccountNumberList.add(text);
         }
 
+        public void endProtocol(String text) {
+            this.requiredProtocols.add(text);
+        }
+
         public void endDistributionConfig(String text) {
             this.distributionConfig = new DistributionConfig(
                 origin, callerReference,
                 (String[]) cnamesList.toArray(new String[cnamesList.size()]),
                 comment, enabled, loggingStatus, originAccessIdentity, trustedSignerSelf,
                 (String[]) trustedSignerAwsAccountNumberList.toArray(
-                	new String[trustedSignerAwsAccountNumberList.size()]));
+                	new String[trustedSignerAwsAccountNumberList.size()]),
+                (String[]) requiredProtocols.toArray(
+                    new String[requiredProtocols.size()])
+                );
             returnControlToParentHandler();
         }
 
@@ -426,9 +421,12 @@ public class CloudFrontXmlResponsesSaxParser {
             this.distributionConfig = new StreamingDistributionConfig(
                 origin, callerReference,
                 (String[]) cnamesList.toArray(new String[cnamesList.size()]), comment,
-                enabled, originAccessIdentity, trustedSignerSelf,
+                enabled, loggingStatus, originAccessIdentity, trustedSignerSelf,
                 (String[]) trustedSignerAwsAccountNumberList.toArray(
-                    new String[trustedSignerAwsAccountNumberList.size()]));
+                    new String[trustedSignerAwsAccountNumberList.size()]),
+                (String[]) requiredProtocols.toArray(
+                    new String[requiredProtocols.size()])
+                );
             returnControlToParentHandler();
         }
     }
