@@ -1,8 +1,8 @@
 /*
- * jets3t : Java Extra-Tasty S3 Toolkit (for Amazon S3 online storage service)
- * This is a java.net project, see https://jets3t.dev.java.net/
+ * JetS3t : Java S3 Toolkit
+ * Project hosted at http://bitbucket.org/jmurty/jets3t/
  *
- * Copyright 2006 James Murty
+ * Copyright 2006-2010 James Murty
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -79,20 +79,7 @@ public class XmlResponsesSaxParser {
      */
     public XmlResponsesSaxParser(Jets3tProperties properties) throws S3ServiceException {
         this.properties = properties;
-
-        // Ensure we can load the XML Reader.
-        try {
-            xr = XMLReaderFactory.createXMLReader();
-        } catch (SAXException e) {
-            // oops, lets try doing this (needed in 1.4)
-            System.setProperty("org.xml.sax.driver", "org.apache.crimson.parser.XMLReaderImpl");
-            try {
-                // Try once more...
-                xr = XMLReaderFactory.createXMLReader();
-            } catch (SAXException e2) {
-                throw new S3ServiceException("Couldn't initialize a sax driver for the XMLReader");
-            }
-        }
+        this.xr = ServiceUtils.loadXMLReader();
     }
 
     /**
