@@ -102,6 +102,8 @@ import org.jets3t.service.utils.ServiceUtils;
  * recommend that this service be used to perform any real work.</b>
  * </p>
  *
+ * @deprecated in 0.7.4 -- full removal is imminent.
+ *
  * @author James Murty
  */
 public class SoapS3Service extends S3Service {
@@ -129,18 +131,21 @@ public class SoapS3Service extends S3Service {
     {
         super(awsCredentials, invokingApplicationDescription, jets3tProperties);
 
+        String s3Endpoint = this.jets3tProperties.getStringProperty(
+            "s3service.s3-endpoint", Constants.S3_DEFAULT_HOSTNAME);
+
         locator = new AmazonS3_ServiceLocator();
         if (super.isHttpsOnly()) {
             // Use an SSL connection, to further secure the signature.
             if (log.isDebugEnabled()) {
             	log.debug("SOAP service will use HTTPS for all communication");
             }
-            locator.setAmazonS3EndpointAddress("https://" + Constants.S3_HOSTNAME + "/soap");
+            locator.setAmazonS3EndpointAddress("https://" + s3Endpoint + "/soap");
         } else {
             if (log.isDebugEnabled()) {
             	log.debug("SOAP service will use HTTP for all communication");
             }
-            locator.setAmazonS3EndpointAddress("http://" + Constants.S3_HOSTNAME + "/soap");
+            locator.setAmazonS3EndpointAddress("http://" + s3Endpoint + "/soap");
         }
         // Ensure we can get the stub.
         getSoapBinding();
@@ -731,11 +736,18 @@ public class SoapS3Service extends S3Service {
         String destinationBucketName, String destinationObjectKey,
         AccessControlList acl, Map destinationMetadata, Calendar ifModifiedSince,
         Calendar ifUnmodifiedSince, String[] ifMatchTags, String[] ifNoneMatchTags,
-        String versionId) throws S3ServiceException
+        String versionId, String destinationObjectStorageClass)
+        throws S3ServiceException
     {
         if (versionId != null) {
             throw new S3ServiceException("The SOAP API interface for S3 does not support versioning");
         }
+        if (destinationObjectStorageClass != null
+            && !destinationObjectStorageClass.equals(S3Object.STORAGE_CLASS_STANDARD))
+        {
+            throw new S3ServiceException("The SOAP API interface for S3 does not support "
+                + "non-standard storage classes");
+        }
         try {
             AmazonS3SoapBindingStub s3SoapBinding = getSoapBinding();
             Calendar timestamp = getTimeStamp( System.currentTimeMillis() );
