@@ -1,8 +1,8 @@
 /*
- * jets3t : Java Extra-Tasty S3 Toolkit (for Amazon S3 online storage service)
- * This is a java.net project, see https://jets3t.dev.java.net/
+ * JetS3t : Java S3 Toolkit
+ * Project hosted at http://bitbucket.org/jmurty/jets3t/
  *
- * Copyright 2006 James Murty
+ * Copyright 2006-2010 James Murty
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -64,14 +64,17 @@ public class S3Object extends BaseS3Object implements Cloneable {
     public static final String METADATA_HEADER_CONTENT_LENGTH = "Content-Length";
     public static final String METADATA_HEADER_CONTENT_TYPE = "Content-Type";
     public static final String METADATA_HEADER_CONTENT_ENCODING = "Content-Encoding";
-    public static final String METADATA_HEADER_STORAGE_CLASS = "Storage-Class";
     public static final String METADATA_HEADER_CONTENT_DISPOSITION = "Content-Disposition";
     public static final String METADATA_HEADER_CONTENT_LANGUAGE = "Content-Language";
 
+    public static final String STORAGE_CLASS_STANDARD = "STANDARD";
+    public static final String STORAGE_CLASS_REDUCED_REDUNDANCY = "REDUCED_REDUNDANCY";
+
     private String key = null;
     private String bucketName = null;
     private transient InputStream dataInputStream = null;
     private AccessControlList acl = null;
+    private String storageClass = null;
     private boolean isMetadataComplete = false;
 
     /**
@@ -235,6 +238,7 @@ public class S3Object extends BaseS3Object implements Cloneable {
     public String toString() {
     	return "S3Object [key=" + getKey() + ", bucket=" + (bucketName == null ? "<Unknown>" : bucketName)
     		+ ", lastModified=" + getLastModifiedDate() + ", dataInputStream=" + dataInputStream
+    		+ (getStorageClass() != null ? ", storageClass=" + getStorageClass() : "")
     		+ ", Metadata=" + getMetadataMap() + "]";
     }
 
@@ -470,17 +474,16 @@ public class S3Object extends BaseS3Object implements Cloneable {
      * the storage class of the object.
      */
     public String getStorageClass() {
-    	return (String) getMetadata(METADATA_HEADER_STORAGE_CLASS);
+    	return this.storageClass;
     }
 
     /**
-     * Set the storage class based on information returned from S3.
-     * This method should only by used by code that reads S3 responses.
+     * Set the storage class for this object.
      *
      * @param storageClass
      */
     public void setStorageClass(String storageClass) {
-        addMetadata(METADATA_HEADER_STORAGE_CLASS, storageClass);
+        this.storageClass = storageClass;
     }
 
     /**
@@ -643,18 +646,20 @@ public class S3Object extends BaseS3Object implements Cloneable {
      * @param name
      * @param value
      */
-    public void addMetadata(String name, Object value) {
-        if ((METADATA_HEADER_LAST_MODIFIED_DATE.equals(name)
-             || METADATA_HEADER_DATE.equals(name))
-            && !(value instanceof Date))
+    public void addMetadata(String name, String value) {
+        if (METADATA_HEADER_LAST_MODIFIED_DATE.equals(name)
+            || METADATA_HEADER_DATE.equals(name))
         {
             try {
+                Date parsedDate = null;
                 // We shouldn't get ISO 8601 dates here but let's be paranoid...
         	    if (value.toString().indexOf("-") >= 0) {
-                    value = ServiceUtils.parseIso8601Date(value.toString());
+        	        parsedDate = ServiceUtils.parseIso8601Date(value);
         	    } else {
-                    value = ServiceUtils.parseRfc822Date(value.toString());
+        	        parsedDate = ServiceUtils.parseRfc822Date(value);
         	    }
+                super.addMetadata(name, parsedDate);
+                return;
             } catch (ParseException e) {
             	if (log.isErrorEnabled()) {
             		log.error("Unable to parse value we expect to be a valid date: "
@@ -675,7 +680,14 @@ public class S3Object extends BaseS3Object implements Cloneable {
         Iterator iter = metadata.entrySet().iterator();
         while (iter.hasNext()) {
         	Map.Entry entry = (Map.Entry) iter.next();
-        	addMetadata(entry.getKey().toString(), entry.getValue());
+        	Object value = entry.getValue();
+        	if (value instanceof String) {
+                addMetadata(entry.getKey().toString(), (String) value);
+        	} else if (value instanceof Date) {
+                addMetadata(entry.getKey().toString(), (Date) value);
+        	} else if (value instanceof S3Owner) {
+                addMetadata(entry.getKey().toString(), (S3Owner) value);
+        	}
         }
     }
 
@@ -711,6 +723,7 @@ public class S3Object extends BaseS3Object implements Cloneable {
         clone.acl = acl;
         clone.isMetadataComplete = isMetadataComplete;
         clone.dataInputFile = dataInputFile;
+        clone.storageClass = storageClass;
         clone.addAllMetadata(getMetadataMap());
         return clone;
     }
