@@ -1,6 +1,6 @@
 /*
- * jets3t : Java Extra-Tasty S3 Toolkit (for Amazon S3 online storage service)
- * This is a java.net project, see https://jets3t.dev.java.net/
+ * JetS3t : Java S3 Toolkit
+ * Project hosted at http://bitbucket.org/jmurty/jets3t/
  *
  * Copyright 2006 James Murty
  *
@@ -359,29 +359,19 @@ public class AWSCredentials implements Serializable {
             // Read version information from AWS credentials file.
             version = ServiceUtils.readInputStreamLineToString(inputStream, Constants.DEFAULT_ENCODING);
 
-            if (!version.startsWith(VERSION_PREFIX)) {
-                // Either this is not a valid AWS Credentials file, or it's an obsolete version.
-                // Try decrypting using the obsolete approach.
-                friendlyName = version;
+            // Extract the version number
+            versionNum = Integer.parseInt(version.substring(VERSION_PREFIX.length()));
+            // Read algorithm and friendly name from file.
+            algorithm = ServiceUtils.readInputStreamLineToString(inputStream, Constants.DEFAULT_ENCODING);
+            friendlyName = ServiceUtils.readInputStreamLineToString(inputStream, Constants.DEFAULT_ENCODING);
 
-                if (!partialReadOnly) {
-                    encryptionUtil = EncryptionUtil.getObsoleteEncryptionUtil(password);
-                }
-            } else {
-                // Extract the version number
-                versionNum = Integer.parseInt(version.substring(VERSION_PREFIX.length()));
-                // Read algorithm and friendly name from file.
-                algorithm = ServiceUtils.readInputStreamLineToString(inputStream, Constants.DEFAULT_ENCODING);
-                friendlyName = ServiceUtils.readInputStreamLineToString(inputStream, Constants.DEFAULT_ENCODING);
+            if (!partialReadOnly) {
+                encryptionUtil = new EncryptionUtil(password, algorithm, EncryptionUtil.DEFAULT_VERSION);
+            }
 
-                if (!partialReadOnly) {
-                    encryptionUtil = new EncryptionUtil(password, algorithm, EncryptionUtil.DEFAULT_VERSION);
-                }
-
-                if (3 <= versionNum) {
-                    String credentialsType = ServiceUtils.readInputStreamLineToString(inputStream, Constants.DEFAULT_ENCODING);
-                    usingDevPay = (DEVPAY_TYPE_NAME.equals(credentialsType));
-                }
+            if (3 <= versionNum) {
+                String credentialsType = ServiceUtils.readInputStreamLineToString(inputStream, Constants.DEFAULT_ENCODING);
+                usingDevPay = (DEVPAY_TYPE_NAME.equals(credentialsType));
             }
 
             if (partialReadOnly) {
