@@ -1,8 +1,8 @@
 /*
- * jets3t : Java Extra-Tasty S3 Toolkit (for Amazon S3 online storage service)
- * This is a java.net project, see https://jets3t.dev.java.net/
+ * JetS3t : Java S3 Toolkit
+ * Project hosted at http://bitbucket.org/jmurty/jets3t/
  *
- * Copyright 2006 James Murty
+ * Copyright 2006-2010 James Murty
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -62,12 +62,6 @@ import org.jets3t.service.utils.ServiceUtils;
 /**
  * Utility class to handle encryption and decryption in the JetS3t suite.
  * <p>
- * The encryption method used by JetS3t has changed after version 0.4.0, from standard triple DES
- * to the proper password-based encryption method PBEWithMD5AndDES. For backwards compatibility this
- * class retains the ability to decrypt items encrypted with the original 0.4.0 algorithm, however
- * these mechanisms are deprecated and could be removed from JetS3t at any time.
- * </p>
- * <p>
  * This class uses properties obtained through {@link org.jets3t.service.Jets3tProperties}.
  * For more information on these properties please refer to
  * <a href="http://jets3t.s3.amazonaws.com/toolkit/configuration.html">JetS3t Configuration</a>
@@ -168,107 +162,6 @@ public class EncryptionUtil {
         this(encryptionKey, "PBEWithMD5AndDES", DEFAULT_VERSION);
     }
 
-    /**
-     * Constructs the class using the obsolete methodology from 0.4.0, which used the
-     * DESede algorithm instead of a PBE version.
-     *
-     * @param encryptionKey
-     * @param encryptionScheme
-     * @param blockMode
-     * @param paddingMode
-     * @throws InvalidKeyException
-     * @throws NoSuchAlgorithmException
-     * @throws NoSuchPaddingException
-     * @throws InvalidKeySpecException
-     * @throws UnsupportedEncodingException
-     * @throws
-     *
-     * @deprecated
-     */
-    private EncryptionUtil(String encryptionKey, String encryptionScheme, String blockMode,
-        String paddingMode) throws InvalidKeyException, NoSuchAlgorithmException,
-        NoSuchPaddingException, InvalidKeySpecException, UnsupportedEncodingException
-    {
-        byte[] KEY_BASE_BYTES = new byte[] {
-            (byte)0xC2, (byte)0xAB, (byte)0xE2, (byte)0x80, (byte)0xA0, (byte)0x0E,
-            (byte)0xC2, (byte)0xBB, (byte)0xC3, (byte)0xA6, (byte)0xE2, (byte)0x80,
-            (byte)0x94, (byte)0x72, (byte)0x3D, (byte)0xC3, (byte)0xB4, (byte)0x18,
-            (byte)0x14, (byte)0x51, (byte)0xC5, (byte)0x92, (byte)0x20, (byte)0x79,
-            (byte)0xE2, (byte)0x84, (byte)0xA2, (byte)0x53, (byte)0x34, (byte)0x43,
-            (byte)0x2E, (byte)0x24, (byte)0x53, (byte)0xC3, (byte)0xBF, (byte)0xC3,
-            (byte)0x92, (byte)0x74, (byte)0xCB, (byte)0x9A, (byte)0xC3, (byte)0xA0,
-            (byte)0xC3, (byte)0xA1, (byte)0x49, (byte)0xC3, (byte)0x8C, (byte)0x5B,
-            (byte)0xE2, (byte)0x88, (byte)0x86, (byte)0x4F, (byte)0xC3, (byte)0x8B,
-            (byte)0xC3, (byte)0x96, (byte)0xC3, (byte)0x84, (byte)0x75, (byte)0x40,
-            (byte)0xE2, (byte)0x80, (byte)0x9D, (byte)0x1C, (byte)0xC2, (byte)0xA9,
-            (byte)0x64, (byte)0x46, (byte)0x16, (byte)0x54, (byte)0x17, (byte)0x03,
-            (byte)0xC2, (byte)0xB4, (byte)0xC3, (byte)0xA4, (byte)0xE2, (byte)0x81,
-            (byte)0x84, (byte)0xC3, (byte)0xA1, (byte)0x4E, (byte)0x68, (byte)0xC3,
-            (byte)0x8B, (byte)0xC3, (byte)0xAA, (byte)0x76, (byte)0xC2, (byte)0xAB,
-            (byte)0x1D, (byte)0xE2, (byte)0x80, (byte)0x94, (byte)0xC2, (byte)0xA3,
-            (byte)0x6C, (byte)0xC3, (byte)0xBB, (byte)0x5E, (byte)0x75, (byte)0xE2,
-            (byte)0x80, (byte)0x9D, (byte)0xC3, (byte)0x83, (byte)0x10, (byte)0xCF,
-            (byte)0x80, (byte)0x2B, (byte)0x74, (byte)0xC5, (byte)0x93, (byte)0x3A,
-            (byte)0xC3, (byte)0x80, (byte)0x4B, (byte)0x37, (byte)0x51, (byte)0xC2,
-            (byte)0xA7, (byte)0xE2, (byte)0x88, (byte)0x9E, (byte)0x48, (byte)0x3E,
-            (byte)0xE2, (byte)0x80, (byte)0x9E, (byte)0x3A, (byte)0x69, (byte)0xC3,
-            (byte)0x8A, (byte)0x75, (byte)0x11, (byte)0xE2, (byte)0x80, (byte)0xB0,
-            (byte)0xC3, (byte)0x94, (byte)0xC3, (byte)0xBC, (byte)0x51, (byte)0xC3,
-            (byte)0x93, (byte)0x23, (byte)0xE2, (byte)0x80, (byte)0xBA, (byte)0xC2,
-            (byte)0xA5, (byte)0x31, (byte)0xE2, (byte)0x80, (byte)0x94, (byte)0x7A,
-            (byte)0x6A, (byte)0xC2, (byte)0xB5, (byte)0xE2, (byte)0x81, (byte)0x84,
-            (byte)0xE2, (byte)0x80, (byte)0xB9, (byte)0x29, (byte)0x31, (byte)0x6F,
-            (byte)0xE2, (byte)0x80, (byte)0xB0, (byte)0xC3, (byte)0xB7, (byte)0x4D,
-            (byte)0xC3, (byte)0x98, (byte)0x35, (byte)0x44, (byte)0x46, (byte)0xC3,
-            (byte)0xAD, (byte)0xC2, (byte)0xAB, (byte)0xC5, (byte)0xB8, (byte)0x2E,
-            (byte)0x23, (byte)0x63, (byte)0x3B, (byte)0xC2, (byte)0xAF, (byte)0xC2,
-            (byte)0xB7, (byte)0xEF, (byte)0xA3, (byte)0xBF, (byte)0xCB, (byte)0x86,
-            (byte)0xC3, (byte)0x8C, (byte)0x42, (byte)0xCE, (byte)0xA9, (byte)0xE2,
-            (byte)0x88, (byte)0x86, (byte)0x76, (byte)0xE2, (byte)0x84, (byte)0xA2
-        };
-
-        algorithm = "DESede/CBC/PKCS5Padding";
-        encryptionKey = encryptionKey + new String(KEY_BASE_BYTES, Constants.DEFAULT_ENCODING);
-
-        int keyOffset = 0;
-        byte spec[] = new byte[8];
-        for (int specOffset = 0; specOffset < spec.length; specOffset++) {
-            keyOffset = (keyOffset + 7) % encryptionKey.length();
-            spec[specOffset] = encryptionKey.getBytes()[keyOffset];
-        }
-
-        KeySpec keySpec = new DESedeKeySpec(encryptionKey.getBytes());
-        algParamSpec = new IvParameterSpec(spec);
-        key = SecretKeyFactory.getInstance(encryptionScheme).generateSecret(keySpec);
-    }
-
-    /**
-     * Creates an EncryptionUtil initialised using the original algorithm configuration as used
-     * in JetS3t releases prior to version 0.5.0. This method is deprecated as the crypto
-     * configuration used has changed, and this method is provided for backwards compatibility only.
-     * This method could be removed at any time.
-     *
-     * @param encryptionKey
-     * the key (password) to use when encrypting data.
-     * @return
-     * an EncryptionUtil object configured in a way compatible with the crypto mechanisms used in
-     * the JetS3t release version 0.4.0.
-     *
-     * @throws InvalidKeyException
-     * @throws NoSuchAlgorithmException
-     * @throws NoSuchPaddingException
-     * @throws InvalidKeySpecException
-     * @throws UnsupportedEncodingException
-     *
-     * @deprecated as of JetS3t version 0.5.0
-     */
-    public static EncryptionUtil getObsoleteEncryptionUtil(String encryptionKey) throws
-        InvalidKeyException, NoSuchAlgorithmException, NoSuchPaddingException, InvalidKeySpecException,
-        UnsupportedEncodingException
-    {
-        return new EncryptionUtil(encryptionKey, "DESede", "CBC", "PKCS5Padding");
-    }
-
     protected Cipher initEncryptModeCipher() throws NoSuchAlgorithmException, NoSuchPaddingException,
         InvalidKeyException, InvalidAlgorithmParameterException
     {
