@@ -1,6 +1,6 @@
 /*
- * jets3t : Java Extra-Tasty S3 Toolkit (for Amazon S3 online storage service)
- * This is a java.net project, see https://jets3t.dev.java.net/
+ * JetS3t : Java S3 Toolkit
+ * Project hosted at http://bitbucket.org/jmurty/jets3t/
  *
  * Copyright 2006-2008 James Murty
  *
@@ -1004,12 +1004,6 @@ public class FileComparer {
                         String metadataLocalFileDate = (String) s3Object.getMetadata(
                             Constants.METADATA_JETS3T_LOCAL_FILE_DATE);
 
-                        // Try to retrieve the date using the deprecated metadata name
-                        if (metadataLocalFileDate == null) {
-                            metadataLocalFileDate = (String) s3Object.getMetadata(
-                                Constants.METADATA_JETS3T_LOCAL_FILE_DATE_DEPRECATED);
-                        }
-
                         if (metadataLocalFileDate == null) {
                             // This is risky as local file times and S3 times don't match!
                             if (!assumeLocalLatestInMismatch && log.isWarnEnabled()) {
