@@ -1,8 +1,8 @@
 /*
- * jets3t : Java Extra-Tasty S3 Toolkit (for Amazon S3 online storage service)
- * This is a java.net project, see https://jets3t.dev.java.net/
+ * JetS3t : Java S3 Toolkit
+ * Project hosted at http://bitbucket.org/jmurty/jets3t/
  *
- * Copyright 2006 James Murty
+ * Copyright 2006-2010 James Murty
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -34,11 +34,11 @@ import java.util.TreeMap;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
+import org.apache.commons.httpclient.DefaultHttpMethodRetryHandler;
 import org.apache.commons.httpclient.Header;
 import org.apache.commons.httpclient.HostConfiguration;
 import org.apache.commons.httpclient.HttpClient;
 import org.apache.commons.httpclient.HttpMethod;
-import org.apache.commons.httpclient.HttpMethodRetryHandler;
 import org.apache.commons.httpclient.HttpVersion;
 import org.apache.commons.httpclient.MultiThreadedHttpConnectionManager;
 import org.apache.commons.httpclient.NTCredentials;
@@ -351,48 +351,41 @@ public class RestUtils {
         }
         clientParams.setParameter(HttpMethodParams.USER_AGENT, userAgent);
 
-        clientParams.setParameter("http.protocol.version", HttpVersion.HTTP_1_1);
-        clientParams.setBooleanParameter("http.protocol.expect-continue", true);
+        clientParams.setParameter(HttpMethodParams.PROTOCOL_VERSION, HttpVersion.HTTP_1_1);
+        clientParams.setBooleanParameter(HttpMethodParams.USE_EXPECT_CONTINUE, true);
 
         // Replace default error retry handler.
         final int retryMaxCount = jets3tProperties.getIntProperty("httpclient.retry-max", 5);
 
-        clientParams.setParameter(HttpClientParams.RETRY_HANDLER, new HttpMethodRetryHandler() {
+        clientParams.setParameter(HttpClientParams.RETRY_HANDLER, new DefaultHttpMethodRetryHandler(retryMaxCount, false) {
             public boolean retryMethod(HttpMethod httpMethod, IOException ioe, int executionCount) {
-                if (executionCount > retryMaxCount) {
-                    if (log.isWarnEnabled()) {
-                        log.warn("Retried connection " + executionCount
-                            + " times, which exceeds the maximum retry count of " + retryMaxCount);
+                if (super.retryMethod(httpMethod, ioe, executionCount)) {
+                    if  (ioe instanceof UnrecoverableIOException) {
+                        if (log.isDebugEnabled()) {
+                            log.debug("Deliberate interruption, will not retry");
+                        }
+                        return false;
                     }
-                    return false;
-                }
 
-                if  (ioe instanceof UnrecoverableIOException) {
+                    // Release underlying connection so we will get a new one (hopefully) when we retry.
+                    httpMethod.releaseConnection();
+
                     if (log.isDebugEnabled()) {
-                        log.debug("Deliberate interruption, will not retry");
+                        log.debug("Retrying " + httpMethod.getName() + " request with path '"
+                            + httpMethod.getPath() + "' - attempt " + executionCount
+                            + " of " + retryMaxCount);
                     }
-                    return false;
-                }
-
-                // Release underlying connection so we will get a new one (hopefully) when we retry.
-                httpMethod.releaseConnection();
-
-                if (log.isDebugEnabled()) {
-                    log.debug("Retrying " + httpMethod.getName() + " request with path '"
-                        + httpMethod.getPath() + "' - attempt " + executionCount
-                        + " of " + retryMaxCount);
-                }
-
-                // Build the authorization string for the method.
-                try {
-                    awsRequestAuthorizer.authorizeHttpRequest(httpMethod);
-                } catch (Exception e) {
-                    if (log.isWarnEnabled()) {
-                        log.warn("Unable to generate updated authorization string for retried request", e);
+                    // Build the authorization string for the method.
+                    try {
+                        awsRequestAuthorizer.authorizeHttpRequest(httpMethod);
+                    } catch (Exception e) {
+                        if (log.isWarnEnabled()) {
+                            log.warn("Unable to generate updated authorization string for retried request", e);
+                        }
                     }
+                    return true;
                 }
-
-                return true;
+                return false;
             }
         });
 
@@ -419,8 +412,8 @@ public class RestUtils {
     /**
      * Initialises this service's HTTP proxy by auto-detecting the proxy settings.
      */
-    public static void initHttpProxy(HttpClient httpClient) {
-        initHttpProxy(httpClient, true, null, -1, null, null, null);
+    public static void initHttpProxy(HttpClient httpClient, Jets3tProperties jets3tProperties) {
+        initHttpProxy(httpClient, jets3tProperties, true, null, -1, null, null, null);
     }
 
     /**
@@ -429,8 +422,10 @@ public class RestUtils {
      * @param proxyHostAddress
      * @param proxyPort
      */
-    public static void initHttpProxy(HttpClient httpClient, String proxyHostAddress, int proxyPort) {
-        initHttpProxy(httpClient, false, proxyHostAddress, proxyPort, null, null, null);
+    public static void initHttpProxy(HttpClient httpClient, String proxyHostAddress,
+        int proxyPort, Jets3tProperties jets3tProperties) {
+        initHttpProxy(httpClient, jets3tProperties, false,
+            proxyHostAddress, proxyPort, null, null, null);
     }
 
     /**
@@ -446,11 +441,12 @@ public class RestUtils {
      * will be used. If the proxy domain is null, a
      * {@link UsernamePasswordCredentials} credentials provider will be used.
      */
-    public static void initHttpProxy(HttpClient httpClient, String proxyHostAddress,
-        int proxyPort, String proxyUser, String proxyPassword, String proxyDomain)
+    public static void initHttpProxy(HttpClient httpClient, Jets3tProperties jets3tProperties,
+        String proxyHostAddress, int proxyPort, String proxyUser,
+        String proxyPassword, String proxyDomain)
     {
-        initHttpProxy(httpClient, false, proxyHostAddress, proxyPort,
-            proxyUser, proxyPassword, proxyDomain);
+        initHttpProxy(httpClient, jets3tProperties, false,
+            proxyHostAddress, proxyPort, proxyUser, proxyPassword, proxyDomain);
     }
 
     /**
@@ -462,7 +458,8 @@ public class RestUtils {
      * @param proxyPassword
      * @param proxyDomain
      */
-    protected static void initHttpProxy(HttpClient httpClient, boolean proxyAutodetect,
+    protected static void initHttpProxy(HttpClient httpClient,
+        Jets3tProperties jets3tProperties, boolean proxyAutodetect,
         String proxyHostAddress, int proxyPort, String proxyUser,
         String proxyPassword, String proxyDomain)
     {
@@ -490,10 +487,12 @@ public class RestUtils {
         }
         // If no explicit settings are available, try autodetecting proxies (unless autodetect is disabled)
         else if (proxyAutodetect) {
+            String s3Endpoint = jets3tProperties.getStringProperty(
+                "s3service.s3-endpoint", Constants.S3_DEFAULT_HOSTNAME);
             // Try to detect any proxy settings from applet.
             ProxyHost proxyHost = null;
             try {
-                proxyHost = PluginProxyUtil.detectProxy(new URL("http://" + Constants.S3_HOSTNAME));
+                proxyHost = PluginProxyUtil.detectProxy(new URL("http://" + s3Endpoint));
                 if (proxyHost != null) {
                     if (log.isInfoEnabled()) {
                         log.info("Using Proxy: " + proxyHost.getHostName() + ":" + proxyHost.getPort());
