@@ -1,8 +1,8 @@
 /*
- * jets3t : Java Extra-Tasty S3 Toolkit (for Amazon S3 online storage service)
- * This is a java.net project, see https://jets3t.dev.java.net/
+ * JetS3t : Java S3 Toolkit
+ * Project hosted at http://bitbucket.org/jmurty/jets3t/
  *
- * Copyright 2006 James Murty
+ * Copyright 2006-2010 James Murty
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -40,6 +40,7 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.SimpleTimeZone;
+import java.util.regex.Pattern;
 
 import javax.crypto.Mac;
 import javax.crypto.spec.SecretKeySpec;
@@ -51,6 +52,9 @@ import org.jets3t.service.Constants;
 import org.jets3t.service.S3Service;
 import org.jets3t.service.S3ServiceException;
 import org.jets3t.service.model.S3Object;
+import org.xml.sax.SAXException;
+import org.xml.sax.XMLReader;
+import org.xml.sax.helpers.XMLReaderFactory;
 
 /**
  * General utility methods used throughout the jets3t project.
@@ -505,6 +509,7 @@ public class ServiceUtils {
 
     /**
      * Computes the MD5 hash of the data in the given input stream and returns it as a hex string.
+     * The provided input stream is consumed and closed by this method.
      *
      * @param is
      * @return
@@ -557,13 +562,13 @@ public class ServiceUtils {
      * @return
      * The S3 bucket name represented by the DNS host name, or null if none.
      */
-    public static String findBucketNameInHostname(String host) {
+    public static String findBucketNameInHostname(String host, String s3Endpoint) {
         String bucketName = null;
         // Bucket name is available in URL's host name.
-        if (host.endsWith(Constants.S3_HOSTNAME)) {
+        if (host.endsWith(s3Endpoint)) {
             // Bucket name is available as S3 subdomain
             bucketName = host.substring(0,
-                host.length() - Constants.S3_HOSTNAME.length() - 1);
+                host.length() - s3Endpoint.length() - 1);
         } else {
             // URL refers to a virtual host name
             bucketName = host;
@@ -585,7 +590,9 @@ public class ServiceUtils {
      * @return
      * the object referred to by the URL components.
      */
-    public static S3Object buildObjectFromUrl(String host, String urlPath) throws UnsupportedEncodingException {
+    public static S3Object buildObjectFromUrl(String host, String urlPath, String s3Endpoint)
+        throws UnsupportedEncodingException
+    {
         if (urlPath.startsWith("/")) {
             urlPath = urlPath.substring(1); // Ignore first '/' character in url path.
         }
@@ -593,8 +600,8 @@ public class ServiceUtils {
         String bucketName = null;
         String objectKey = null;
 
-        if (!Constants.S3_HOSTNAME.equals(host)) {
-            bucketName = findBucketNameInHostname(host);
+        if (!s3Endpoint.equals(host)) {
+            bucketName = findBucketNameInHostname(host, s3Endpoint);
         } else {
             // Bucket name must be first component of URL path
             int slashIndex = urlPath.indexOf("/");
@@ -613,6 +620,57 @@ public class ServiceUtils {
         return object;
     }
 
+    /**
+     * Returns true if the given bucket name can be used as a component of a valid
+     * DNS name. If so, the bucket can be accessed using requests with the bucket name
+     * as part of an S3 sub-domain. If not, the old-style bucket reference URLs must be
+     * used, in which case the bucket name must be the first component of the resource
+     * path.
+     *
+     * @param bucketName
+     * the name of the bucket to test for DNS compatibility.
+     */
+    public static boolean isBucketNameValidDNSName(String bucketName) {
+        if (bucketName == null || bucketName.length() > 63 || bucketName.length() < 3) {
+            return false;
+        }
+
+        // Only lower-case letters, numbers, '.' or '-' characters allowed
+        if (!Pattern.matches("^[a-z0-9][a-z0-9.-]+$", bucketName)) {
+            return false;
+        }
+
+        // Cannot be an IP address, i.e. must not contain four '.'-delimited
+        // sections with 1 to 3 digits each.
+        if (Pattern.matches("([0-9]{1,3}\\.){3}[0-9]{1,3}", bucketName)) {
+            return false;
+        }
+
+        // Components of name between '.' characters cannot start or end with '-',
+        // and cannot be empty
+        String[] fragments = bucketName.split("\\.");
+        for (int i = 0; i < fragments.length; i++) {
+            if (Pattern.matches("^-.*", fragments[i])
+                || Pattern.matches(".*-$", fragments[i])
+                || Pattern.matches("^$", fragments[i]))
+            {
+                return false;
+            }
+        }
+
+        return true;
+    }
+
+    public static String generateS3HostnameForBucket(String bucketName,
+        boolean isDnsBucketNamingDisabled, String s3Endpoint)
+    {
+        if (isBucketNameValidDNSName(bucketName) && !isDnsBucketNamingDisabled) {
+            return bucketName + "." + s3Endpoint;
+        } else {
+            return s3Endpoint;
+        }
+    }
+
     /**
      * Returns a user agent string describing the jets3t library, and optionally the application
      * using it, to server-side services.
@@ -648,4 +706,35 @@ public class ServiceUtils {
                 : "");
     }
 
+    /**
+     * Find a SAX XMLReader by hook or by crook, with work-arounds for
+     * non-standard platforms.
+     *
+     * @return an initialized XML SAX reader
+     */
+    public static XMLReader loadXMLReader() throws S3ServiceException {
+        // Try loading the default SAX reader
+        try {
+            return XMLReaderFactory.createXMLReader();
+        } catch (SAXException e) {
+            // Ignore failure
+        }
+
+        // No dice using the standard approach, try loading alternatives...
+        String[] altXmlReaderClasspaths = new String[] {
+            "org.apache.crimson.parser.XMLReaderImpl",  // JDK 1.4
+            "org.xmlpull.v1.sax2.Driver",  // Android
+        };
+        for (int i = 0; i < altXmlReaderClasspaths.length; i++) {
+            String xmlReaderClasspath = altXmlReaderClasspaths[i];
+            try {
+                return XMLReaderFactory.createXMLReader(xmlReaderClasspath);
+            } catch (SAXException e) {
+                // Ignore failure
+            }
+        }
+        // If we haven't found and returned an XMLReader yet, give up.
+        throw new S3ServiceException("Failed to initialize a SAX XMLReader");
+    }
+
 }
